function outfiles = dynareirf(tit,irfreplic,irflength,var_list,impsize,irfstart,filename,levelvars,trendvar)

global oo_ M_ options_

if nargin < 1, tit      = M_.exo_names; end
if nargin < 2, irfreplic= options_.replic;end
    if irfreplic==0, irfreplic=10; end
if nargin < 3, irflength= options_.irf; end
    if irflength==0, irflength=20; end
if nargin < 4, var_list = M_.endo_names;end
if nargin < 5, impsize  = [2;1;-1;-2];  end
if nargin < 6, irfstart = 1;            end
if nargin < 7, filename = [''];         end
if nargin < 8, impul    = num2str(impsize); end
if ~isfield(options_,'steady_irf'); options_.steady_irf=0; end
if ~isfield(options_,'stoch_steady'); options_.stoch_steady=0; end



if options_.order == 1
    options_.replic = 1;
elseif options_.order == 3
    options_.k_order_solver = 1;
end

if exist('levelvars','var')
    levelvarpos = zeros(M_.endo_nbr,1);
    for i=1:size(levelvars,1)
        levelvarpos(strmatch(levelvars(i,:),M_.endo_names,'exact'),1)=1;
    end
end

plotstyle=['-+k';':b ';':k ';'-b '];
impul=strcat(num2str(impsize),repmat('\sigma',length(impsize),1));

n   = size(var_list,1);
ivar= zeros(n,1);
for i=1:n
    i_tmp = strmatch(var_list(i,:),M_.endo_names,'exact');
	if isempty(i_tmp)
        error (['One of the specified variables does not exist']) ;
    else
        ivar(i) = i_tmp;
    end 
end

SS(M_.exo_names_orig_ord,M_.exo_names_orig_ord)=M_.Sigma_e+1e-14*eye(M_.exo_nbr);
cs = transpose(chol(SS));
    
y=zeros(M_.endo_nbr,irflength,length(impsize));

for i=1:size(tit,1)
    for k=1:length(impsize)
        shocktmp = impsize(k)*cs(M_.exo_names_orig_ord,M_.exo_names_orig_ord(strmatch(tit(i,:),M_.exo_names)));
        y(:,:,k) = irf(oo_.dr, shocktmp, irflength, options_.drop, irfreplic, options_.order);
        if isfield(options_,'steady_irf') && (options_.steady_irf == 1)
            if isfield(options_,'stoch_steady') && options_.stoch_steady ==1
                ystemp = oo_.mean';
            else
                ystemp = oo_.dr.ys;
            end
            y(:,:,k)=y(:,:,k) + repmat(ystemp,1,irflength);

        elseif isfield(options_,'relative_irf') && (options_.relative_irf==1)             
            ystemp = oo_.dr.ys;
            ystemp(oo_.dr.ys==0)=exp(oo_.dr.ys(oo_.dr.ys==0));
            y(:,:,k)=y(:,:,k)./repmat(ystemp,1,irflength)*100;
        end
        if exist('levelvarpos','var')
            y(:,:,k)=levelvarpos * cumsum(squeeze(y(strmatch(trendvar,M_.endo_names),:,k))) + y(:,:,k);
        end

    end    
	irfs   = [];
	mylist = [];
    
	for j = 1:n
        if max(y(ivar(j),:,:)) - min(y(ivar(j),:,:)) > 1e-10
            irfs  = cat(1,irfs,y(ivar(j),:,:));
            assignin('base',['allirfs_' deblank(tit(i,:))],irfs)
            if isfield(M_,'endo_full_names')
                namepos(j)= strmatch(var_list(j,:),M_.endo_names,'exact');
                if iscellstr(M_.endo_full_names(namepos,:))
                    mylist = strvcat(mylist,deblank(char(M_.endo_full_names(namepos(j),:))));
                else 
                    mylist = strvcat(mylist,deblank(var_list(j,:)));
                end
            else
                mylist = strvcat(mylist,deblank(var_list(j,:)));
            end
        end
    end
    
    if (irfstart==0) && ((options_.steady_irf ~= 1) || ~isfield(options_,'steady_irf'))
        zeroinsert=zeros(n,1,length(impsize));
        irfs=cat(2,zeroinsert,irfs);
    elseif irfstart==0 && (options_.steady_irf == 1)
        steadyinsert=repmat(ystemp(namepos),[1 1 length(impsize)]);
        irfs=cat(2,steadyinsert,irfs);
    end

save(strcat(deblank(filename),'_',deblank(tit(i,:))), 'irfs', 'var_list', 'irflength', 'impsize', 'irfstart')

if options_.nograph == 0
number_of_plots_to_draw = size(irfs,1);
[nbplt,nr,nc,lr,lc,nstar] = pltorg(number_of_plots_to_draw);

if nbplt == 1
    finaltitle = [filename ' model : Shock to' ' ' tit(i,:)];
    hh = figure('Name',finaltitle);
    for j = 1:number_of_plots_to_draw
    	subplot(nr,nc,j);
        for k=1:length(impsize)
            plot(irfstart:irflength,transpose(irfs(j,:,k)),plotstyle(mod(k-1,length(plotstyle))+1,:),'linewidth',1.5);
            hold on
        end
        if options_.steady_irf == 1
            plot([irfstart irflength],[ystemp(namepos(j)) ystemp(namepos(j))],'-r','linewidth',0.5);
        else
            plot([irfstart irflength],[0 0],'-r','linewidth',0.5);
        end
        hold off
        xlim([irfstart irflength]);
        title(deblank(mylist(j,:)),'Interpreter','none','FontSize',12);
        eval(['print -depsc2 ' M_.fname '_IRF_' deblank(tit(i,:)) '.eps']);
    end
%    suptitle(finaltitle)
    leg=legend(deblank(num2str(impul)),'Location','SouthEast');              
    set(leg,'FontSize',12);

else
    for fig = 1:nbplt-1
        finaltitle = ['Model ' filename ': Shock to ' tit(i,:) ', figure ' int2str(fig)];
        hh = figure('Name',finaltitle);
        for plt = 1:nstar
            subplot(nr,nc,plt);
            for k=1:length(impsize)
                plot(irfstart:irflength,transpose(irfs((fig-1)*nstar+plt,:,k)),plotstyle(mod(k-1,length(plotstyle))+1,:),'linewidth',1.5);
                hold on
            end
            if options_.steady_irf == 1
                plot([irfstart irflength],[ystemp(namepos(j)) ystemp(namepos(j))],'-r','linewidth',0.5);
            else
                plot([irfstart irflength],[0 0],'-r','linewidth',0.5);
            end
            hold off
            xlim([irfstart irflength]);
            title(deblank(mylist((fig-1)*nstar+plt,:)),'Interpreter','none');
        end
%        suptitle(finaltitle)
        leg=legend(deblank(num2str(impul)),'Location','SouthEast');
        set(leg,'FontSize',12);
    end
    
    finaltitle = ['Model ' filename ': Shock to ' tit(i,:) ', figure ' int2str(nbplt)];
    hh = figure('Name',finaltitle);
    m=0;
    for plt = 1:number_of_plots_to_draw-(nbplt-1)*nstar;
        m = m+1;
        subplot(lr,lc,m);
        for k=1:length(impsize)
            for k=1:length(impsize)
            plot(irfstart:irflength,transpose([irfs((nbplt-1)*nstar+plt,:,k)]),plotstyle(mod(k-1,length(plotstyle))+1,:),'linewidth',2);
            hold on
            end
            if options_.steady_irf == 1
                plot([irfstart irflength],[ystemp(namepos(j)) ystemp(namepos(j))],'-r','linewidth',0.5);
            else
                plot([irfstart irflength],[0 0],'-r','linewidth',0.5);
            end
        hold off
        xlim([irfstart irflength]);
        title(deblank(mylist((nbplt-1)*nstar+plt,:)), 'Interpreter','none','FontSize',12);
        end
    end
%	suptitle(finaltitle)
	leg=legend(deblank(num2str(impul)),'Location','SouthEast');
	set(leg,'FontSize',12);
end
end
end
end