function [ADPP]=adpp(data,F, varargin)
%This program computes the average duration in a time series from peak to
%peak according to the Bry-Boschan identification method. It requires the
%programm file brybos. 
%The user may alternatively specify a dating input where (1) stands for peak, 
%(-1) for a trough and (0) else (input for varargin as T*1 vector). It must have the same 
%dimensions as the data and can not have empty observations.

% The user must input the data as a T*1 vector and speecify the frequency
% F=0 for monthly data
% F=1 for quarterly data
% F=2 for yearly data
% The input data can not have empty observations.

%The output is the average duration for series m.

%Program written by Sebastian Weber, Graduate Institute of International
%Studies, Geneva

warning off MATLAB:divideByZero

if nargin==2
   date=brybos(data,F);
else
    date=varargin{:};
end

P=find(date(:,1)>0); 
T=find(date(:,1)<0);
[p1 k]=size(P);
[t1 k]=size(T);
if p1<2
    ADPP=0/0;
else
    for j=1:p1-1
        Dur(j,1)=P(j+1,1)-P(j,1);
    end
    ADPP=sum(Dur)/(p1-1);  %average duration peak to peak
end
    
warning on MATLAB:divideByZero

