%% Panel file: panel.xls



clear ;
currdir = pwd;
addpath(genpath([pwd '\supportfiles']))

% Options
selectcountriescharts = [ 1 2 3 4 5 ]; % select countries to be plotted
                   % 
qoq        = 0;    % =1 does the analysis in quarter-on-quarter terms, else analysis is done in yoy
loggrowth  = 0;    % =1 growth rates generated using logs, else X[t]/X[t-4]-1 or X[t]/X[t-1]-1 if qoq=1;
lambdahp   = 1600; % setting lambda for Hodrick-Prescott;
LBK=6; UBK=32;     % options for Baxter-King filter
F=1; D=1; Min=6; % Turning Point parameters (F=1 frwuency quarterly, D=1, Min = 6)

plotcharts = 1;    % =1 generates graphical output
plothist   = 0;    % =1 generates output of histograms
trendcharts= 1;    % =1 generates graphical output for HP and BK trends
histdiff   = 0;    % =1 plots histograms at end using differences instead of growth rates


BBQ        = 1;
present_correl_table = 0;  %Present tables of correlations
outputtype = 0;  % 1 generates only Turning Point output, 
                 % 2 only moments, any other number produces both

%Bootstrap options                 
nbootstrp       = 200; %Bootstrap iterations for confidence interval of Skewness, Kurtosis
bootstrmethod   = 'stationary';
bootstrblocksize= 20; % block size to replicate autocorrelation of the data. Real variables should take value 10 and nominal variables hould take value 20


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%  Bringing data in shape  %%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
[dataraw, textdata] = xlsread('DataPanel.xls','data'); % extracting numbers and table headers
variables           = deblank(textdata(1,4:end)');  % removing blanks in variable names
datashort             = dataraw(:,3:end);             % identifing data
datashort(datashort==0) = NaN;                          % change zeros in the data to NaNs

[t V]   = size(dataraw); % characterise data size
I       = 5;             % there are I countries
t       = t/I;           % Periods covered

% datashort=[];            % Shorten data deleting last d observations
% for i = 1:I              
%     timelong = [1+(i-1)*(t+d):i*(t+d)-d]';
%     datashort     = [datashort; dataraw(timelong,:)];
% end
    
for i=1:I               % Idntify country names
    names(i,:)=textdata(2+(t)*(i-1),1)';
end
clear textdata

for i = 1:size(variables,1) % Name series by column header in Excel
    eval([variables{i} ' = datashort(:,i);'])
end

% Compute measures of real wages
realcompgdp= nomcomp ./ gdpdef;
%ER         = 1-ur/100;  % employment rate is defined here 1- unemployment rate 

% All data and variable names
variables   = [variables;'realcompgdp'];
nomcomppos  =  strmatch('nomcomp',variables,'exact');
gdpdefpos   =  strmatch('gdpdef',variables,'exact');
realcompgdppos  =  strmatch('realcompgdp',variables,'exact');
emplpos     =  strmatch('empl',variables,'exact');
urpos       =  strmatch('ur',variables,'exact');
vacpos   =  strmatch('vac',variables,'exact');
gdppos      =  strmatch('gdp',variables,'exact');
totalcappos      =  strmatch('totalcap',variables,'exact');

datashort    = [datashort realcompgdp];
datashortpc  = datashort./repmat(pop,1,size(datashort,2)); % Data in per capita terms (divided by working age population)
logdatashort = log(datashort);              % Log series
logdatashortpc = log(datashortpc);          % Log series

% Data in gross 4-quarter growth rates (with suffix 'g') and 4-quarter differences (with suffix 'd')
for i = 1:I
    time     = 1+(i-1)*t:i*t;
    if qoq == 1;
        if loggrowth ==1
            datashortg(time,:)   = ([NaN(1,size(datashort  ,2));log(datashort(2+(i-1)*t:i*t,:)) - log(datashort  (1+(i-1)*t:i*t-1,:))]); %computing growth rates through logs
            datashortpcg(time,:) = ([NaN(1,size(datashortpc,2));log(datashortpc(2+(i-1)*t:i*t,:)) - log(datashortpc(1+(i-1)*t:i*t-1,:))]);
        else
            datashortg(time,:)   = ([NaN(1,size(datashort  ,2));  datashort(2+(i-1)*t:i*t,:) ./   datashort(1+(i-1)*t:i*t-1,:)]-1);
            datashortpcg(time,:) = ([NaN(1,size(datashortpc,2));datashortpc(2+(i-1)*t:i*t,:) ./ datashortpc(1+(i-1)*t:i*t-1,:)]-1);
        end
    else
        if loggrowth ==1
            datashortg(time,:)   = ([NaN(4,size(datashort  ,2));log(datashort(5+(i-1)*t:i*t,:)) - log(datashort  (1+(i-1)*t:i*t-4,:))]); %computing growth rates through logs
            datashortpcg(time,:) = ([NaN(4,size(datashortpc,2));log(datashortpc(5+(i-1)*t:i*t,:)) - log(datashortpc(1+(i-1)*t:i*t-4,:))]);
        else
            datashortg(time,:)   = ([NaN(4,size(datashort  ,2));  datashort(5+(i-1)*t:i*t,:) ./   datashort(1+(i-1)*t:i*t-4,:)]-1);
            datashortpcg(time,:) = ([NaN(4,size(datashortpc,2));datashortpc(5+(i-1)*t:i*t,:) ./ datashortpc(1+(i-1)*t:i*t-4,:)]-1);
        end
    end
    datashortd(time,:)      = ([NaN(4,size(datashort  ,2));  datashort(5+(i-1)*t:i*t,:) -    datashort(1+(i-1)*t:i*t-4,:)]-1);
    datashortpcd(time,:)    = ([NaN(4,size(datashortpc,2));datashortpc(5+(i-1)*t:i*t,:) -  datashortpc(1+(i-1)*t:i*t-4,:)]-1);
end;

% Name growth series by column header adding suffix 'infl' or 'diff' for
% series in in differences
for v = 1:size(variables,1)
    variablesinfl{v,1}     = [variables{v} 'infl'];
    eval([variablesinfl{v,1} '   = datashortg(:,v);']);

    variablespcinfl{v,1}   = [variables{v} 'pcinfl'];
    eval([variablespcinfl{v,1} ' = datashortpcg(:,v);']);

    variablesdiff{v,1}     = [variables{v} 'diff'];
    eval([variablesdiff{v,1} '   = datashortd(:,v);']);
    variablespcdiff{v,1}   = [variables{v} 'diff'];
    eval([variablespcdiff{v,1} ' = datashortpcd(:,v);']);
end;

% Decide which series should be in per capita terms and which ones not
listlevels  = strvcat('nomcomp','gdpdef','realcompgdp','ur','vac','vacadapt');
listlevelspc= strvcat('unempl','empl','totalcap','gdp');
for v=1:length(variables)
    if strmatch(variables(v),listlevelspc,'exact')
        data(:,v)   = datashortpc(:,v);
        datag(:,v)  = datashortpcg(:,v);
        datad(:,v)  = datashortpcd(:,v);
        variables{v}=[char(variables(v)) 'pc'];
    else
        data(:,v)  = datashort(:,v);
        datag(:,v) = datashortg(:,v);
        datad(:,v) = datashortd(:,v);
    end
end
% end of data preparation

%% HP-Filter, Band-Pass filter of level series (data) and gross growth rates (datag)

% Decide which series should be transmformed in logs before taking HP
listlogs  = strvcat('nomcomp','gdpdef','realcompgdp','empl','unempl','totalcap','gdp');
for v=1:length(variables)
        dataforfilter(:,v) = log(data(:,v));
        variablesforfilter{v}=['l' char(variables(v))];
end
% Filtering with HP-filter and with Baxter King
trendl = nan(size(data,1),size(data,2));            % preparing matrice
for i=1:I                                           % across countries
    if trendcharts ==1; 
        figure('Name',['HP filtering ' names{i}]); 
    end
    time = 1+(i-1)*t:i*t;
    for v=1:length(variables)     
        % across variables
        if v == 1 || v == 2; %captures nominal wages and GDP deflator
%            dataforfilter(time,v) = [NaN;dataforfilter(time(2:end),v)-dataforfilter(time(1:end-1),v)];
            dataforfilter(time,v) = [NaN;data(time(2:end),v)./data(time(1:end-1),v)-1];            
        end
        timev = time(~isnan(dataforfilter(time,v)));
        trend(time,v) = nan(length(time),1);
        if ~isempty(timev)
            trend(timev,v)  = hpfilter(dataforfilter(timev,v),lambdahp);
            if v == 1 || v == 2; %captures nominal wages and GDP deflator
                cycleBK(timev,v)= bkfilter(dataforfilter(timev,v),LBK,UBK);
            else 
                cycleBK(timev,v)= exp(bkfilter(dataforfilter(timev,v),LBK,UBK));
            end
        end
        if trendcharts ==1;
            subplot(ceil(sqrt(length(variables))),ceil(sqrt(length(variables))),v)
            plot(time,trend(time,v),time,dataforfilter(time,v))
            title(variablesforfilter{v})
            axis tight
        end
    end
end
cycleHP = [dataforfilter(:,1:2)-trend(:,1:2) exp(dataforfilter(:,3:end)-trend(:,3:end))];
cycleBK(isnan(cycleHP)) = NaN;

if trendcharts==1;
    for i=1:I 	% across countries
        figure('Name',['Comparison HP and BK cycles ' names{i}]);
        time = 1+(i-1)*t:i*t;
        for v=1:length(variables)	% across variables
            subplot(ceil(sqrt(length(variables))),ceil(sqrt(length(variables))),v)
            plot(time,cycleBK(time,v),time,cycleHP(time,v))
            title(variablesforfilter{v})
            axis tight
        end
    legend('BK','HP');    
    end
end

%% Moments for data: HP-filtered, yoy growth rates, qoq growth

% Prepare labels for data moments
col =strvcat('Mean','Median','StDev','RelStDev','Skew','corrGDP','corrEMP','corrNOMWAG','corrREALWAG','corrGDPDEF');
colcountries = [];
for c = 1:size(col,1)
    colcountries = [colcountries; repmat(col(c,:),I,1)];
end
labels = [colcountries repmat(' ',length(colcountries),1) repmat([char(names)],size(col,1),1)];


% Prepare labels for Turning Point analysis
column = strvcat('ADPP','ADTT','AD','ADTP','ADPT','RATIO','GRPT','GRTP','GRRAT');
colcountriesTP = [];
for n = 1:size(names,1)
    colcountriesTP = [colcountriesTP; repmat(names(n),size(column,1),1)];
end
labelsTP = [char(colcountriesTP) repmat(' ',length(colcountriesTP),1) repmat(column,size(names,1),1)];

allmomplot=[];
for datype = 2:4
    clear me med sd rsd skew kurt
%     if datype == 1;
%         datatable = data;
%         variablestab = char(variables);
%         titletab = ['Moments / Turning points in levels'];
%         logflag = 1;
    if datype == 2
        datatable = cycleHP;
        variablestab = char(variablesforfilter);
        titletab = ['Moments / Turning points HP detr. data'];
        logflag = 1;
    elseif datype == 3
        datatable = cycleBK;
        variablestab = char(variablesforfilter);
        titletab = ['Moments / Turning points band-pass filtered'];        
        logflag = 1;
    elseif datype == 4
        datatable = datag;
        variablestab = char(variables);
        titletab = ['Moments of variables in growth rates'];
        if loggrowth ==1; titletab= ['Moments of variables in log differences']; end
        logflag = 0;
    end
    
    %% Turning Points
    [t k3]=size(datatable);
    t=t/I;
    V=size(variables,1);

    if BBQ==1
        [dating]=mBBQinput(datatable,I,logflag);
    else
        [dating]=hardpag(datatable,I,F,D,Min);
    end

    %%
    % Computing duration and growth rates
    G = 0; % G=0 the growth rate is computed year-to-year change and taking the average over the period.
           % G=1 the growth rate is calculating using continous
           % compounding.
           
    TPstat = []; p_opt = []; b_opt = []; p_optcorr = []; b_optcorr = [];
    
	for i= selectcountriescharts  % across selected countries;
        time=1+t*(i-1):t*i;
        lt = length(time);
        ltnan = sum(~isnan(datatable(time,:)));

        % Moments
        me(i,:)   = nanmean(datatable(time,:));     %Mean
        med(i,:)  = nanmedian(datatable(time,:));   %Median
        sd(i,:)   = nanstd(datatable(time,:));      %Std deveiation
        datademean= datatable(time,:)-repmat(me(i,:),lt,1); 
        sdsd(i,:) = sqrt(nansum((datademean.^2 - repmat(nanmean(datademean.^2),lt,1)).^2)./(ltnan-1)); %Std. dev. of Std. deviation
        rsd(i,:)  = sd(i,:)./sd(i,gdppos);          % Std. deviation relative to output
        skew(i,:) = skewness(datatable(time,:),0);  % Skewness
%        stat3tmp  = (datatable(time,:) - repmat(me(i,:),t,1)).^3;
%        skew2(i,:) = nanmean(stat3tmp)./nanstd(datatable(time,:)).^3;
        %stat3(i,:)= nanmean(stat3tmp)./nanstd(sign(stat3tmp).*abs(stat3tmp).^(1/3)).^3;
        kurt(i,:) = kurtosis(datatable(time,:),0);  % Kurtosis
        
        % Auocorrelation
        autocordatatmp = [];                        
        for j=1:10
            autocordatatmp = [autocordatatmp; nansum((datatable(time(1)+j-1:time(end),:)-repmat(me(i,:),lt-j+1,1))...
                .*(datatable(time(1):time(end)-j+1,:)-repmat(me(i,:),lt-j+1,1)))...
                ./(sd(i,:)).^2./(ltnan-j)];
        end
        autocordata(i,:,:) = autocordatatmp;
 
        % Correlations
        cor(:,:,i) = corrcoef(datatable(time,:),'rows','pairwise');
        cor_Y(i,:) = cor(gdppos,:,i);
        cor_n(i,:) = cor(emplpos,:,i);
        cor_wn(i,:)= cor(nomcomppos,:,i);
        cor_wr(i,:)= cor(realcompgdppos,:,i);
        cor_pi(i,:)= cor(gdpdefpos,:,i);            
                
        if datype ==2 || datype ==3  % the cases of HP- and BK-detrended variables
            outputtable = [100*nanstd(datatable(time,:))' (sd(i,:)./sd(i,gdppos))' cor(gdppos,:,i)'];
            varforoutput = strvcat('StDev','RelStDev','Corr w. GDP');
            headerscell =mat2cell(varforoutput,ones(1,size(varforoutput,1)));
            labelscell  =variables;
            if datype ==2 
                filenameSWP = ['Table3_HP-detrended_data_moments' names{i,:} '.tex'];
            elseif datype == 3
                filenameSWP = ['Table3alt_BK-detrended_moments' names{i,:} '.tex'];
            end
            matrix2SWP(outputtable, filenameSWP, 'rowLabels', labelscell, 'columnLabels', headerscell, 'alignment', 'r', 'format', '%-6.2f');

        elseif datype ==4  %the case of growth rates or log differences
            % Computing bootstrap samples 
            [skewbootstrp(i,:,:) hs autocor(i,:,:) skewH0bootstrp(i,:,:) skewH02bootstrp(i,:,:) optblock0]= ...
                bootstrp(nbootstrp,@skewness,bootstrmethod,bootstrblocksize,datatable(time,:));

            % For reference: optimal bootstrap block length
            optblocklength = optblockl(datatable(time(1+4):time(end),:));
            p_opt = [p_opt [1./optblocklength(1,:)]' [1./optblock0(1,:)]'];
            b_opt = [b_opt [optblocklength(2,:)]' [optblock0(2,:)]'];
            
            %Moments of bootstrapped samples
            skewmean(i,:)       = nanmean(skewbootstrp(i,:,:));  %Mean
            skewmedian(i,:)     = nanmedian(skewbootstrp(i,:,:));%Median
            skewsd(i,:)         = nanstd(skewbootstrp(i,:,:));   %Skewness
            
            % One sided tests: which side to test for (follows the ordering of the variables 
            signskew = [1 1 -1 1 -1 -1 -1 -1 1];
            selectp2 = [0 0  1 0  1  1  1  1 0];
            selectp1 = 1-selectp2;
            
            % confidence interval
            skewbootci(i,:,:) = [prctile(squeeze(skewbootstrp(i,:,:)),10);prctile(squeeze(skewbootstrp(i,:,:)),90)];
            skewbootci1tmp    = squeeze(skewbootci(i,:,:));
            skewbootci1(i,:,:)= sum(skewbootci1tmp.*[selectp1;selectp2]);

            %confidence percentiles with respect to 0 skewness
            p_above_zero=squeeze(sum((sort(skewbootstrp(i,:,:)>0)))/size(skewbootstrp,2))';
            p_below_zero=squeeze(sum((sort(skewbootstrp(i,:,:)<0)))/size(skewbootstrp,2))';
            prctls_zero = [p_below_zero;p_above_zero];
            prctls_zero_select(i,:) = sum(prctls_zero.*[selectp1;selectp2]);
            
            %p-value based on H0 (3rd moments, skenwess)
            p_above_empskew=squeeze(sum((squeeze(skewH0bootstrp(i,:,:))>repmat(skew(i,:),nbootstrp,1)))/size(skewH0bootstrp,2));
            p_below_empskew=squeeze(sum((squeeze(skewH0bootstrp(i,:,:))<repmat(skew(i,:),nbootstrp,1)))/size(skewH0bootstrp,2));
            pval_skew(i,:) = sum([p_below_empskew;p_above_empskew].*[selectp2;selectp1]);
            
            % Produce Latex output for yoy growth rates
            outputtable = [100*nanmean(datatable(time,:))' 100*nanmedian(datatable(time,:))'...
                           100*nanstd(datatable(time,:))'  100*sdsd(i,:)' (sd(i,:)./sd(i,gdppos))'...
                           skewness(datatable(time,:),0)' squeeze(skewbootci(i,1,:)) squeeze(skewbootci(i,2,:))...
                           prctls_zero_select(i,:)' pval_skew(i,:)'];
            varforoutput= strvcat('Mean','Median'  ,'StDev'   ,'SD.SD' ,'RelStDev','Skew','lower CI','upper CI','percentile','Bootstrapped p_value');
            headerscell = mat2cell(varforoutput,ones(1,size(varforoutput,1)));
            labelscell  = variables;
            if qoq == 1; filenameadd = 'qoq'; else filenameadd = 'yoy'; end;
            matrix2SWP(outputtable, ['Table1alt_Datadescription_' filenameadd '_blocksize' num2str(bootstrblocksize) '_' names{i,:} '.tex'], 'rowLabels', labelscell, 'columnLabels', headerscell, 'alignment', 'r', 'format', '%-6.2f');
        end
        
        %% Moments with outlier correction
        datatablecorr = datatable(time,:);
        if datype==4 && outputtype ~= 1
            datatablecorr(datatablecorr>repmat(nanmedian(datatablecorr)+3.5*nanstd(datatablecorr),lt,1))=NaN;
            datatablecorr(datatablecorr<repmat(nanmedian(datatablecorr)-3.5*nanstd(datatablecorr),lt,1))=NaN;
            ltnancorr = sum(~isnan(datatablecorr(1:lt,:)));
            
            % Corrections for taking into account outliers
            mecorr(i,:)    = nanmean(datatablecorr);
            medcorr(i,:)   = nanmedian(datatablecorr);
            sdcorr(i,:)    = nanstd(datatablecorr);
            datademeancorr = datatablecorr(1:lt,:)-repmat(mecorr(i,:),lt,1);
            sdsdcorr(i,:)  = sqrt(nansum((datademeancorr.^2 - repmat(nanmean(datademeancorr.^2),lt,1)).^2)./(ltnancorr-1));
            rsdcorr(i,:)   = sdcorr(i,:)./sdcorr(i,gdppos);
            skewcorr(i,:)  = skewness(datatablecorr,0);
%            stat3corrtmp  = (datatablecorr - repmat(mecorr(i,:),t,1)).^3;
%            stat3corr(i,:)= nanmean(stat3corrtmp)./nanstd(sign(stat3corrtmp).*abs(stat3corrtmp).^(1/3)).^3;
            kurtcorr(i,:)  = kurtosis(datatablecorr,0);

            
            % Auocorrelation
%             autocordatacorrtmp = [];                        
%             for j=1:10
%             autocordatacorrtmp = [autocordatacorrtmp; nansum((datatablecorr(time(1)+j-1:time(end),:)-repmat(mecorr(i,:),lt-j+1,1))...
%                 .*(datatablecorr(time(1):time(end)-j+1,:)-repmat(mecorr(i,:),lt-j+1,1)))...
%                 ./(sdcorr(i,:)).^2./(ltnan-j)];
%             end
%             autocordatacorr(i,:,:) = autocordatacorrtmp;
            
            % Correlations
            corcorr(:,:,i) = corrcoef(datatablecorr,'rows','pairwise');
            corcorr_Y(i,:) = corcorr(gdppos,:,i);
            corcorr_n(i,:) = corcorr(emplpos,:,i);
            corcorr_wn(i,:)= corcorr(nomcomppos,:,i);
            corcorr_wr(i,:)= corcorr(realcompgdppos,:,i);
            corcorr_pi(i,:)= corcorr(gdpdefpos,:,i);

            if datype==4
                datatablecorrnonan = datatablecorr(~isnan(datatablecorr));
                
                % Computing bootstrap samples with outlier-corrected series
                [skewbootstrpcorr(i,:,:) hs autocorcorr(i,:,:) skewH0bootstrpcorr(i,:,:) skewH02bootstrpcorr(i,:,:)  optblock0corr]=...
                    bootstrp(nbootstrp,@skewness,bootstrmethod,bootstrblocksize,datatablecorr);

                % For reference: optimal bootstrap block length with outlier-corrected series
                optblocklengthcorr = optblockl(datatablecorr(5:end,:));                
                p_optcorr = [p_optcorr [1./optblocklengthcorr(1,:)]'  [1./optblock0corr(1,:)]'];
                b_optcorr = [b_optcorr [optblocklengthcorr(2,:)]' [optblock0corr(2,:)]'];
                
                %Bootstrap distribution moments:
                skewmeancorr(i,:)       = nanmean(skewbootstrpcorr(i,:,:));
                skewmedcorr(i,:)        = nanmedian(skewbootstrpcorr(i,:,:));
                skewsdcorr(i,:)         = nanstd(skewbootstrpcorr(i,:,:));                
                
                %test statistics percentile
                skewH0p10corr(i,:,:) = [prctile(squeeze(skewH0bootstrpcorr(i,:,:)),10);prctile(squeeze(skewH0bootstrpcorr(i,:,:)),90)];
                skewH02p10corr(i,:,:) = [prctile(squeeze(skewH02bootstrpcorr(i,:,:)),10);prctile(squeeze(skewH02bootstrpcorr(i,:,:)),90)];
    
                % confidence interval
                skewbootcicorr(i,:,:) = [prctile(squeeze(skewbootstrpcorr(i,:,:)),10);prctile(squeeze(skewbootstrpcorr(i,:,:)),90)];
                skewbootci1corrtmp    = squeeze(skewbootcicorr(i,:,:));
                skewbootci1corr(i,:,:) = sum(skewbootci1corrtmp.*[selectp1;selectp2]);
                
                %percentiles confidence interval
                p_above_zerocorr=squeeze(sum((sort(skewbootstrpcorr(i,:,:)>0)))/size(skewbootstrpcorr,2))';
                p_below_zerocorr=squeeze(sum((sort(skewbootstrpcorr(i,:,:)<0)))/size(skewbootstrpcorr,2))';
                prctls_zerocorr = [p_below_zerocorr;p_above_zerocorr];
                prctls_zero_selectcorr(i,:) = sum(prctls_zerocorr.*[selectp1;selectp2]);
            
                %p-value based on H0 (3rd moments, skenwess)
                p_above_empskewcorr=squeeze(sum((squeeze(skewH0bootstrpcorr(i,:,:))>repmat(skewcorr(i,:),nbootstrp,1)))/nbootstrp);
                p_below_empskewcorr=squeeze(sum((squeeze(skewH0bootstrpcorr(i,:,:))<repmat(skewcorr(i,:),nbootstrp,1)))/nbootstrp);
                pval_skewcorr(i,:) = sum([p_below_empskewcorr;p_above_empskewcorr].*[selectp2;selectp1]);
                
                %p-value based on alternative H0 when 3rd moments for each
                %bootstrap sample are divided by std. deviation
%                 p2_above_empskewcorr=squeeze(sum((squeeze(skewH02bootstrpcorr(i,:,:))>repmat(stat3corr(i,:),nbootstrp,1)))/nbootstrp);
%                 p2_below_empskewcorr=squeeze(sum((squeeze(skewH02bootstrpcorr(i,:,:))<repmat(stat3corr(i,:),nbootstrp,1)))/nbootstrp);
%                 p2val_skewcorr(i,:) = sum([p2_below_empskewcorr;p2_above_empskewcorr].*[selectp2;selectp1]);
            end
        end
        
        if datype == 4 && outputtype~=1
            datagcorr(time,:) = datatablecorr;
   
            % Produce Latex output for CORRECTED growth rates
            outputtable = [...
                100*nanmean(datatablecorr)' 100*nanmedian(datatablecorr)'...
                100*nanstd(datatablecorr)' 100*sdsdcorr(i,:)' (sdcorr(i,:)./sdcorr(i,gdppos))'...
                skewness(datatablecorr,0)' squeeze(skewbootcicorr(i,1,:)) squeeze(skewbootcicorr(i,2,:))...
                skewsdcorr(i,:)' prctls_zero_selectcorr(i,:)' pval_skewcorr(i,:)'];
            varforoutput = strvcat(...
                'Mean','Median',...
                'StDev','SD.SD','RelStDev',...
                'Skew','lower CI','upper CI',...
                'Skew.SD','prctl','pskew');
            headerscell =mat2cell(varforoutput,ones(1,size(varforoutput,1)));
            labelscell  =variables;
            if qoq == 1; filenameadd = 'qoq'; else filenameadd = 'yoy'; end;
            matrix2SWP(outputtable, ['Table1_Datadescription_' filenameadd '_blocksize' num2str(bootstrblocksize) '_corrected_' names{i,:} '.tex'], 'rowLabels', labelscell, 'columnLabels', ...
            headerscell, 'alignment', 'r', 'format', '%-6.2f');
        end

        %% Turning Points  %%%%%%%%%%%%%%%%%%%%%%%%%%
        if (datype == 2 || datype == 3)  && outputtype ~= 2
            for v=1:V
                date=dating(time,v);
                TPstattmp(:,v)=[adpp(datatable(time,v),F,date);
                                adtt(datatable(time,v),F,date);
                                (adpp(datatable(time,v),F,date) + adtt(datatable(time,v),F,date))/2;
                                adtp(datatable(time,v),F,date);
                                adpt(datatable(time,v),F,date);
                                adtp(datatable(time,v),F,date) / adpt(datatable(time,v),F,date);
                                4*grratept(datatable(time,v),F,G,date);
                                4*grratetp(datatable(time,v),F,G,date);
                                -grratetp(datatable(time,v),F,G,date)./grratept(datatable(time,v),F,G,date)];
            end
            TPstat=[TPstat;TPstattmp];
            allTPstat(i,:,:,datype) = TPstattmp'; %country, variable, turning point statistic, datatype
        end
    end
    
        varpresentskew = {'nomcomp','gdpdef','realcompgdp','ur','emplpc','vac','totalcappc','gdppc'};
        for vars = 1:size(varpresentskew,2)
            varsel(vars) = strmatch(varpresentskew(vars),variables,'exact');
        end
        countryreorder = [1 2 3 4 5];
        if datype == 4 && outputtype~=1;
            skewcorrtmp = skewcorr(countryreorder,varsel);
            prctls_zero_selectcorrtmp = prctls_zero_selectcorr(countryreorder,varsel)';
            pval_skewcorrtmp = pval_skewcorr(countryreorder,varsel);
            skewout = [skewcorrtmp(:) prctls_zero_selectcorrtmp(:) pval_skewcorrtmp(:)];
            skewoutlabel = strvcat('Skew','prctl','pskew');
            headerscell = mat2cell(skewoutlabel,ones(1,size(skewoutlabel,1)));
            selectcountry = {'DE';'FR';'UK';'US';'EA'};
            countryvariable = [];
                
            for i=1:8
                countryvariable=[countryvariable;strcat(repmat(variables(varsel(i)),5,1),selectcountry)];
            end
        
            labelscell  =countryvariable; 
            matrix2SWP(skewout, ['Skewness_percentiles_p-values' filenameadd char(bootstrmethod) num2str(bootstrblocksize) '_corrected.tex'], 'rowLabels', labelscell, 'columnLabels', headerscell, 'alignment', 'r', 'format', '%-6.2f');
        
            namesselect = [];
            for asd = 1:length(selectcountriescharts)
                namesselect = [namesselect names(selectcountriescharts(asd),:) names(selectcountriescharts(asd),:)];
            end
%            matrix2SWP(p_opt, ['AppendTable3_Optimal_block_length_geom_p' filenameadd '.tex'], 'rowLabels', variables, 'columnLabels', namesselect, 'alignment', 'r', 'format', '%-6.2f');
%            matrix2SWP(b_opt, ['AppendTable3_Optimal_block_length_fix_b' filenameadd '.tex'], 'rowLabels', variables, 'columnLabels', namesselect, 'alignment', 'r', 'format', '%-6.2f');
            matrix2SWP(p_optcorr, ['AppendTable3_Optimal_block_length_geom_p_optcorr' filenameadd '.tex'], 'rowLabels', variables, 'columnLabels', namesselect, 'alignment', 'r', 'format', '%-6.2f');
%            matrix2SWP(b_optcorr, ['AppendTable3_Optimal_block_length_fix_b_optcorr' filenameadd '.tex'], 'rowLabels', variables, 'columnLabels', namesselect, 'alignment', 'r', 'format', '%-6.2f');
        end

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % Presenting Turning Points and Moments
    allmom = [me;med;sd;rsd;skew;cor_Y];
    allmomplot(:,:,:,datype) = cat(3,me,med,sd,rsd,skew,cor_Y,cor_n,cor_wn,cor_wr,cor_pi);

    if datype<4 && outputtype ~= 2
        table(titletab,strvcat('vari able',variablestab),labelsTP,TPstat,size(char(variables),2)+1,2,2);
        if datype == 2; 
            matrix2SWP(TPstat, ['Table2_Turning_Points_HP.tex'], 'rowLabels', cellstr(labelsTP), 'columnLabels', cellstr(variablestab), 'alignment', 'r', 'format', '%-6.2f');
            matrix2SWP(TPstat, ['AppendTable5_Turning_Points_HP.tex'], 'rowLabels', cellstr(labelsTP), 'columnLabels', cellstr(variablestab), 'alignment', 'r', 'format', '%-6.2f');
        elseif datype == 3; 
            matrix2SWP(TPstat, ['AppendTable6_Turning_Points_BK.tex'], 'rowLabels', cellstr(labelsTP), 'columnLabels', cellstr(variablestab), 'alignment', 'r', 'format', '%-6.2f');
        end;
        
    elseif datype==4 && outputtype ~= 1
        table(titletab,strvcat('vari able',variablestab),labels,allmom,size(char(variables),2)+1,2,2);
    	allmom = [mecorr;medcorr;sdcorr;rsdcorr;skewcorr;corcorr_Y;corcorr_n;corcorr_wn;corcorr_wr;corcorr_pi];
        table([titletab '- corrected'],strvcat('vari able',variablestab),labels,allmom,size(char(variables),2)+1,2,2);    
    end

    % Presenting correlations for detrended data, and in growth rates / differences
    if datype >= 2 && outputtype ~= 1 && present_correl_table ==1;
        variables_for_correlation = ceil(size(cor,1)/2);
        for i = 1:I
            time=1+t*(i-1):t*i;            
            table(['Correlations ' char(names(i,:)) ' ' titletab],strvcat('vari able',variablestab(1:variables_for_correlation,:)),...
                [repmat([char(names(i,:)) ' '],size(variablestab,1),1) variablestab],squeeze(cor(:,1:variables_for_correlation,i)),10,12,2);

        end
    end
end

%% Graphical output

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Computing the distribution under H0
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if (plotcharts ==1) && (outputtype ~= 1)
    selectcountry = {'FR';'DE';'UK';'US';'EA'};
    varpresentskew = {'nomcomp','gdpdef','realcompgdp','ur','emplpc','vac','totalcappc','gdppc'};
    maxskew = squeeze(max(max(skewH0bootstrpcorr)));
    minskew = squeeze(min(min(skewH0bootstrpcorr)));
    for vars = 1:length(varpresentskew)
        v = strmatch(varpresentskew(vars),variables,'exact');
        if qoq == 1; filenameadd = 'qoq'; else filenameadd = 'yoy'; end;        
        figname = ['AppendFig1_left_Bootstrapped_skewness_distribution_under_H0' filenameadd '_blocklength' num2str(bootstrblocksize) '_' char(variables(v))];
        h = figure('Name',figname);
    	[nhist,xouthist]=hist(squeeze(skewH0bootstrpcorr(:,:,v))',ceil(maxskew(v)-minskew(v))*20);    
        maxmaxnhist=max(max(nhist(:,selectcountriescharts)));
        for j=1:length(selectcountry)
            i = strmatch(selectcountry(j),names,'exact');
            [fdens,xouthist]=ksdensity(squeeze(skewH0bootstrpcorr(i,:,v))',xouthist);
            subplot(3,2,j);            
            bar(xouthist,nhist(:,i)/nbootstrp)
            hold on
                 plot(xouthist,fdens/max(fdens)*max(nhist(:,i)/nbootstrp))
                 plot([skewcorr(i,v) skewcorr(i,v)], [0 maxmaxnhist],'k')
                 %plot([skewmeancorr(i,v) skewmeancorr(i,v)], [0 maxmaxnhist],'k:')
                 plot([skewmedcorr(i,v) skewmedcorr(i,v)], [0 maxmaxnhist],'k:')
                 plot([skewH0p10corr(i,1,v) skewH0p10corr(i,1,v)], [0 maxmaxnhist],'r:')
                 plot([skewH0p10corr(i,2,v) skewH0p10corr(i,2,v)], [0 maxmaxnhist],'r:')
%                  plot([skewbootci1corr(i,1,v) skewbootci1corr(i,1,v)], [0 maxmaxnhist],'r')                 
                 plot([0 0], [0 maxmaxnhist],'b')                 
            hold off
            axis([minskew(v) maxskew(v) 0 maxmaxnhist/nbootstrp])
            title(['SkewH0 ' char(names(i,:)) ' ' char(variables(v))]);
        end
        hgsave(h,figname);
    end
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Computing the distribution of skewness for all variables in each country
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if (plotcharts ==1) && (outputtype ~= 1)
    selectcountry = {'FR';'DE';'UK';'US';'EA'};
    varpresentskew = {'nomcomp','gdpdef','realcompgdp','ur','emplpc','vac','totalcappc','gdppc'};
    maxskew = squeeze(max(max(skewbootstrpcorr)));
    minskew = squeeze(min(min(skewbootstrpcorr)));
    for vars = 1:length(varpresentskew)
        v = strmatch(varpresentskew(vars),variables,'exact');
        if qoq == 1; filenameadd = 'qoq'; else filenameadd = 'yoy'; end;        
        figname = ['AppendFig1_right_Bootstrapped_skewness_distribution_' filenameadd '_blocklength' num2str(bootstrblocksize) '_' char(variables(v))];
        h = figure('Name',figname);
    	[nhist,xouthist]=hist(squeeze(skewbootstrpcorr(:,:,v))',ceil(maxskew(v)-minskew(v))*15);    
        maxmaxnhist=max(max(nhist(:,selectcountriescharts)));
        for j=1:length(selectcountry)
            i = strmatch(selectcountry(j),names,'exact');
            [fdens,xouthist]=ksdensity(squeeze(skewbootstrpcorr(i,:,v))',xouthist);
%            subplot(ceil(sqrt(length(selectcountry))),ceil(sqrt(length(selectcountry))),j);
            subplot(3,2,j);            
            bar(xouthist,nhist(:,i)/nbootstrp)
            hold on
                 plot(xouthist,fdens/max(fdens)*max(nhist(:,i)/nbootstrp))
                 plot([skewcorr(i,v) skewcorr(i,v)], [0 maxmaxnhist],'k')
                 %plot([skewmeancorr(i,v) skewmeancorr(i,v)], [0 maxmaxnhist],'k:')
                 plot([skewmedcorr(i,v) skewmedcorr(i,v)], [0 maxmaxnhist],'k:')
                 plot([skewbootcicorr(i,1,v) skewbootcicorr(i,1,v)], [0 maxmaxnhist],'r:')
                 plot([skewbootcicorr(i,2,v) skewbootcicorr(i,2,v)], [0 maxmaxnhist],'r:')
                 %plot([skewbootci1corr(i,1,v) skewbootci1corr(i,1,v)], [0 maxmaxnhist],'r')                 
                 plot([0 0], [0 maxmaxnhist],'b')                 
            hold off
            axis([minskew(v) maxskew(v) 0 maxmaxnhist/nbootstrp])
            title(['Skew ' char(names(i,:)) ' ' char(variables(v))]);
        end
        hgsave(h,figname);
    end
end





%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Plot comparison of Turning Point statistics (HP & BK)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% colTP =strvcat('ADPP','ADTT','AD','ADTP','ADPT','RATIO','GRTP','GRPT','GRRAT');
% %if (plotcharts ==1) && (outputtype ~= 2)
% textcolor=['y';'m';'c';'r';'g';'b';'k';'b';'r'];
% figtitle = strvcat('HP-detrended','Band-Pass filtered','level');
% xval = 1:length(names); %names of countries
%     for j = 1:size(allTPstat,3)
%         figure('Name',[deblank(colTP(j,:)) ' of variables'])
%         for v=1:V
%             subplot(ceil(sqrt(V)),ceil(sqrt(V)),v)
%             [sortedvalHP order]=sort(allTPstat(:,v,j,2)); % country, variable, turning point statistic, datatype
%             sortedvallevel = allTPstat(order,v,j,1);
%             sortedvalBK= allTPstat(order,v,j,3);
%             namesordered = names(order);
%             colororder = textcolor(order);
%             if strmatch('RATIO',colTP(j,:),'exact')
%                 plot(xval,sortedvalHP,xval,sortedvalBK,xval,ones(1,xval(end)));
%             else
%                 plot(xval,sortedvalHP,xval,sortedvalBK);
%             end
%         for k=1:length(names)
%         	text(k,sortedvalHP(k)-.5,namesordered(k),'Color',colororder(k));
%         end
%         title(char(variables(v)));
% %        set(gca, 'XTick', xval, 'XTickLabel', namesordered);
% %        axis tight
%         end
%         legend(figtitle)
%     end
% 
% colTP =strvcat('ADPP','ADTT','AD','ADTP','ADPT','RATIO','GRTP','GRPT','GRRAT');
% textcolor=['y';'m';'c';'r';'g';'b';'k';'b';'r'];
% figtitle = strvcat('level');
% xval = 1:length(names); %names of countries
%     for j = 1:size(allTPstat,3)
%         figure('Name',[deblank(colTP(j,:)) ' of variables not filtered'])
%         for v=1:V
%             subplot(ceil(sqrt(V)),ceil(sqrt(V)),v)
%             [sortedvallevel order]=sort(allTPstat(:,v,j,3)); % country, variable, turning point statistic, datatype
%             namesordered = names(order);
%             colororder = textcolor(order);
%             if strmatch('RATIO',colTP(j,:),'exact')
%                 plot(xval,sortedvallevel,xval,ones(1,xval(end)));
%             else
%                 plot(xval,sortedvallevel);
%             end
%         for k=1:length(names)
%         	text(k,sortedvallevel(k)-.5,namesordered(k),'Color',colororder(k));
%         end
%         title(char(variables(v)));
% %        set(gca, 'XTick', xval, 'XTickLabel', namesordered);
% %        axis tight
%         end
%         legend(figtitle)
%     end
% %end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Plot median, relative volatility, Skewness, Correlations
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 
% %col =strvcat('Mean','Median','StDev','RelStDev','Skew','corrGDP','corrEMP','corrHOURS','corrNOMWAG','corrREALWAG');
% if (plotcharts ==1) && (outputtype ~= 1)
% textcolor=['y';'m';'c';'r';'g';'b';'k';'b';'r'];
% figtitle = strvcat('yoy growth rates');
% xval = 1:length(names);
% varord = [11;9;21;1;3;5;14;15;17]
%     for j = 2:size(allmomplot,3)
%         figure('Name',[deblank(col(j,:)) ' of variables'])
%         for count=1:9 %V
%             v = varord(count);
%             subplot(ceil(sqrt(9)),ceil(sqrt(9)),v)
%             [sortedvalg order]=sort(allmomplot(:,v,j,4));
%             sortedvald = allmomplot(order,v,j,5);
% %            sortedvalHP= allmomplot(order,v,j,2);
% %            sortedvalBK= allmomplot(order,v,j,3);
%             namesordered = names(order);
%             colororder = textcolor(order);
%             if ~isempty(strmatch(deblank(col(j,:)),'RelStDev'))
%             	plot(xval,sortedvalg,xval,ones(1,xval(end)));
%             else
%             	plot(xval,sortedvalg,xval,zeros(1,xval(end)));
%             end
%         for k=1:length(names)
%         	text(k,sortedvalg(k)-.1,namesordered(k),'Color',colororder(k));
%         end
%         title(char(variables(v)));
% %        set(gca, 'XTick', xval, 'XTickLabel', namesordered);
%         if j>5; axis([1 I -1 1]); end
%         end
%         legend(figtitle)
%     end
% end




%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Computing the distribution under H02
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%     selectcountry = {'FR';'DE';'UK';'US';'EA'};
%     varpresentskew = {'nomcomp','gdpdef','realcompgdp','ur','emplpc','vac','totalcappc','gdppc'};
%     maxskew = squeeze(max(max(skewH02bootstrpcorr)));
%     minskew = squeeze(min(min(skewH02bootstrpcorr)));
%     for vars = 1:length(varpresentskew)
%         v = strmatch(varpresentskew(vars),variables,'exact');
%         if qoq == 1; filenameadd = 'qoq'; else filenameadd = 'yoy'; end;        
%         figname = ['SkewH02' 'fig_' filenameadd '_' char(bootstrmethod) num2str(bootstrblocksize) '_' char(variables(v))];
%         h = figure('Name',figname);
%     	[nhist,xouthist]=hist(squeeze(skewH02bootstrpcorr(:,:,v))',ceil(maxskew(v)-minskew(v))*20);    
%         maxmaxnhist=max(max(nhist(:,selectcountriescharts)));
%         for j=1:length(selectcountry)
%             i = strmatch(selectcountry(j),names,'exact');
%             [fdens,xouthist]=ksdensity(squeeze(skewH02bootstrpcorr(i,:,v))',xouthist);
%             subplot(3,2,j);            
%             bar(xouthist,nhist(:,i)/nbootstrp)
%             hold on
%                  plot(xouthist,fdens/max(fdens)*max(nhist(:,i)/nbootstrp))
%                  plot([skewcorr(i,v) skewcorr(i,v)], [0 maxmaxnhist],'k')
%                  %plot([skewmeancorr(i,v) skewmeancorr(i,v)], [0 maxmaxnhist],'k:')
%                  plot([skewmedcorr(i,v) skewmedcorr(i,v)], [0 maxmaxnhist],'k:')
%                  plot([skewH02p10corr(i,1,v) skewH02p10corr(i,1,v)], [0 maxmaxnhist],'r:')
%                  plot([skewH02p10corr(i,2,v) skewH02p10corr(i,2,v)], [0 maxmaxnhist],'r:')
% %                  plot([skewbootci1corr(i,1,v) skewbootci1corr(i,1,v)], [0 maxmaxnhist],'r')                 
%                  plot([0 0], [0 maxmaxnhist],'b')                 
%             hold off
%             axis([minskew(v) maxskew(v) 0 maxmaxnhist/nbootstrp])
%             title(['SkewH02 ' char(names(i,:)) ' ' char(variables(v))]);
%         end
%         hgsave(h,figname);
%     end
% %end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Comparing skewness across variables...
% This section produces skewness cross-plots for variable pairs specified by the variable
% varpairs using different filtering methods
% if (plotcharts ==1) && (outputtype ~= 1)
% varpairs = {...
%     {'realwago'   ;'emplpc'},{'realwago'   ;'hours'},{'realwago'   ,'ur'},{'realwago'   ,'vac'},{'realwago'   ,'gdppc'},{'realwago'   ,'privcappc'},...
%     {'realcompgdp';'emplpc'},{'realcompgdp';'hours'},{'realcompgdp','ur'},{'realcompgdp','vac'},{'realcompgdp','gdppc'},{'realcompgdp','privcappc'},...
%     {'realwaggdp' ;'emplpc'},{'realwaggdp' ;'hours'},{'realwaggdp' ,'ur'},{'realwaggdp' ,'vac'},{'realwaggdp' ,'gdppc'},{'realwaggdp' ,'privcappc'}};

% varpairs2 = {{'emplpc';'ur'}     ,{'emplpc';'hours'}     ,{'emplpc','vac'}     ,{'emplpc','GDP'},     {'emplpc','lprod'},...
%     {'hours';'ur'}    ,{'hours';'vac'}    ,{'hours','GDP'}    ,{'hours','lprod'}};

%col =strvcat('Mean','Median','StDev','RelStDev','Skew','corrGDP');
% if plotcharts ==1
% textcolor=['y';'m';'c';'r';'g';'b';'k';'b';'r'];
% figtitle = strvcat('HP-detrended','Band-Pass filtered','yoy growth rates','yoy differences');
% xval = 1:length(names);


% figure('Name','Skewness cross plots')
% textcolor=['y';'m';'c';'r';'g';'b';'k';'b';'r'];
% for p = 1:size(varpairs,2);
%     subplot(4,5,p)
%     varnames=char(varpairs{1,p});
%     var1pos = strmatch(varnames(1,:),variables,'exact');
%     var2pos = strmatch(varnames(2,:),variables,'exact');
%     [var1sorted order]=sort(allmomplot(:,var1pos,5,4));    
%     var2sorted = allmomplot(order,var2pos,5,4);
%     
%     var1sortedHP = allmomplot(order,var1pos,5,2);
%     var2sortedHP = allmomplot(order,var2pos,5,2);
%     var1sortedBK = allmomplot(order,var1pos,5,3);
%     var2sortedBK = allmomplot(order,var2pos,5,3);
% 
% 	namesordered = names(order);
%     plot(var1sorted,var2sorted,'+');
% % This allows for alternative specifications, i.e. HP or BK detrended
% % variables
% %         plot(var1sortedHP,var2sortedHP,'.g');
% %         lsline;
% %         plot(var1sortedBK,var2sortedBK,'*r');
% %         lsline;
% 
%     lsline;
%     hold on 
%         plot([0 0],[-2 2],':k')
%         plot([-2 2],[0 0],':k')
%     hold off 
%     xlabel(['\gamma_1: ' varnames(1,:)]);
% %     if p <= ceil(sqrt(size(varpairs,2)))
%         ylabel(['\gamma_1: ' varnames(2,:)]);
% %     end
% 
% 	for k=1:length(names)
%         text(var1sorted(k),var2sorted(k)-.1,namesordered(k),'Color',colororder(k));
%     end
%     axis([0 2 -2 2])
% end
% end



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% histogram
% 
% if plothist ==1
% for v = 4 %1:size(variables,1)
%     if histdiff == 1  
%         histvar     = datad(:,v);
%         histvarcorr = datadcorr(:,v);
%     else
%         histvar     = datag(:,v);
%         histvarcorr = datagcorr(:,v);
%     end
% 
%     gridsize    = (max(histvar) - min(histvar))/30;
%     xx          = min(histvar):gridsize:max(histvar);
%     figure('Name',char(variables(v)))    
%     for i=1:I
%         time = 1+t*(i-1):t*i;
%         medi     = nanmedian(histvar(time));
%         stddev   = nanstd(histvar(time));
%         skewn    = skewness(histvar(time),0);
%         skewncorr   = skewness(histvarcorr(time),0);
%         histog = hist(histvar(time),xx);
%         histogcorr = histog.*((xx<medi-4*stddev) | (xx>medi+4*stddev));
%         subplot(3,3,i)
%         bar(xx,histog./length(histvar(time)),'b');
%         axis([min(histvar) max(histvar) 0 0.35]);
%         title([names{i} ' \gamma_1' num2str(skewn,3) ' corr:' num2str(skewncorr,3)]);
%         hold on
%             bar(xx,histogcorr./length(histvar(time)),'r');
% %             Normline = normpdf(xx,medi,stddev)*gridsize;
% %             plot(xx,Normline,'g');
%             plot([0 0],[0 0.4],'k');
%             plot([medi  medi],[0 0.4],'b');
%             plot([medi-4*stddev medi-4*stddev],[0 0.4],'r');
%             plot([medi+4*stddev medi+4*stddev],[0 0.4],'r');
%         hold off
%     end
% end
% 
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %% histogram employment, wages
% 
% for v = [urpos realwaggdppos]
%     histvarcorr = datagcorr(:,v);
%     gridsize    = 0.5;
%     xx          = -4:gridsize:8;
%     figure('Name',char(variables(v)))    
%     j=1;
%     for i= [2 3 7 8]
%         time = 1+t*(i-1):t*i;
%         medi     = nanmedian(histvarcorr(time));
%         stddev   = nanstd(histvarcorr(time));
%         skewn    = skewness(histvarcorr(time),0);
%         histog = hist(histvarcorr(time),xx);
%         size(histog)
%         subplot(2,2,j)
%         bar(xx,histog./length(histvarcorr(time)),'b');
%         axis([-4 8 0 0.2]);
%         title([names{i} ' \gamma_1=' num2str(skewn,3)],'FontSize',14);
%         hold on
%             plot([0 0],[0 0.3],'k');
%             plot([medi  medi],[0 0.3],'b');
%         hold off
%     j=j+1;
%     end
% end
% end

