var q, s, n, u, ur, v, wr,                             //labour market
    wrc, dwrc, piew, ytot, y, k, rk, inv, pie, c, tau, omega, 
    DAI, IAC, TobQ, // adjustment costs on investment
    DAC, AC, // adjustment costs on employment
    curlphi, gampi, DGampi, nint, lambda,
    z, risk                    //shocktypes
    ;

varexo e_r e_m e_z;

parameters  g beta b alpha delta
            omegar omegapi omegau 
            theta eta 
            nu psi epsilon chiw psiw
            ADI deltaprime psii // adjustment costs on investment
            chin psin    // adjustment costs on employment
            Nss Yss    
            roz stdez stdem rorisk stderisk  
            sigmam kap rho
            ; 


// Different calibrations:

// Baseline calibration with dnwr
@# include "dwparam_small_baseline.m" 

// Calibration withOUT dnwr
// @# include "dwparam_small_noDWR.m" 

// Calibration with asymmetric adjustment costs on employment
// @# include "dwparam_small_EAC.m"

// Calibration with asymmetric adjustment costs on investment 
// @# include "dwparam_small_IAC.m" 

// Baseline calibration with dnwr and US calibration
// @# include "dwparam_small_US.m" 

// Baseline calibration with dnwr and accomodative mon.policy
// @# include "dwparam_small_MP.m" 


model;

//Labour market
  q  = sigmam*(v/u)^(-theta);
  s  = sigmam*(v/u)^(1-theta);
  n  = (1-rho)*n(-1) + v*q;
  u  = 1 - (1-rho)*n(-1);
  ur = 1-n;
  kap/lambda/q  = curlphi*y - wr*(1+wrc)-DAC/n(-1) + (1-rho)*beta*lambda(+1)/lambda * kap/lambda(+1)/q(+1) + beta*lambda(+1)/lambda * DAC(+1)*n(+1)/(n^2);

// Wages
  tau = 1 + wrc + dwrc*piew/pie^nu 
      - (1-rho) * beta*lambda(+1)/lambda/g * dwrc(+1)*(piew(+1))^2/(pie(+1))^(1+nu);

  omega = eta/(eta+(1-eta)*tau);

  wr*(1+omega*wrc) = omega*(curlphi*y-DAC/n(-1) + (1-rho)* beta*lambda(+1)/lambda * kap/lambda(+1)/q(+1) * (1-(1-s(+1))*(1-omega)*omega(+1)/((1-omega(+1))*omega)))
                       +omega*beta*lambda(+1)/lambda * DAC(+1)*n(+1)/(n^2) + (1-omega)*b;

//////////////////////////////////////////////////////////////////////////
//Employment adjustment costs 
// Quadratic + Linex
   AC  - (chin-1)/2*(n/n(-1)-1)^2 - 1/psin^2*(  exp(-psin*(n/n(-1)-1)) + psin*(n/n(-1)-1)-1);
  DAC  - (chin-1)  *(n/n(-1)-1)   - 1/psin  *(1-exp(-psin*(n/n(-1)-1)));

//////////////////////////////////////////////////////////////////////////
//Wage adjustment costs 
// Quadratic + Linex
   wrc  - (chiw-1)/2*(piew/pie^nu-g)^2 - 1/psiw^2*(  exp(-psiw*(piew/pie^nu-g)) + psiw*(piew/pie^nu-g)-1);
  dwrc  - (chiw-1)  *(piew/pie^nu-g)   - 1/psiw  *(1-exp(-psiw*(piew/pie^nu-g)) );

//////////////////////////////////////////////////////////////////////////
//Production
  ytot  = exp(z)*(n)^alpha * k^(1-alpha);
  y     = alpha*ytot/n;
  rk    = curlphi * (1-alpha)*ytot/k;
//Capital
  k     - (1-delta)*k(-1)/g - inv;

//////////////////////////////////////////////////////////////////////////
// Investment Adjustment costs

  IAC - (ADI-1)/2*(inv/inv(-1)-1)^2 - 1/psii^2*(  exp(-psii*(inv/inv(-1)-1)) + psii*(inv/inv(-1)-1)-1);
  DAI  - (ADI-1)  *(inv/inv(-1)-1)   - 1/psii  *(1-exp(-psii*(inv/inv(-1)-1)));
  TobQ =1 + IAC + DAI*inv/inv(-1) - beta*(lambda(+1)/lambda)*DAI(+1)*(inv(+1)/inv)^2;
  TobQ= rk + beta*lambda(+1)/lambda/g*(TobQ(+1)*(1-delta));

//////////////////////////////////////////////////////////////////////////
// Resource constraint

  c + inv = ytot*(1-gampi) - wrc*wr*n - IAC*inv - AC;

// Euler & Lagrange multiplier
  lambda = beta*nint*exp(risk)*lambda(+1)/g/pie(+1);
  lambda = 1/c;

//Price Adjustment costs & Inflation Philips curve 
  DGampi*pie = epsilon*(curlphi+gampi)-(epsilon-1) + beta*lambda(+1)/lambda* ytot(+1)/ytot * DGampi(+1) * pie(+1);
   gampi = psi/2 * (pie-1)^2;
  DGampi = psi   * (pie-1);

// Wage identity
  piew = g*(wr/wr(-1))*pie;

//Taylor rule reacting to inflation and output growth
  nint   = exp(-stdem*e_m) * (nint(-1))^omegar * (g/beta * pie^omegapi * (ytot/ytot(-1))^omegau)^(1-omegar);

// Shock process
  z     =             roz  *   z(-1) + stdez * e_z;  
  risk   =             rorisk  * risk(-1) + stderisk * (e_r);
end;

initval;
lambda  = lambdass;
tau     = 1;
omega   = eta;
AC      = 0;
DAC     = 0;
TobQ    = 1;
IAC     = 0;
DAI     = 0;
inv     = Iss;
k       = kss; 
n       = Nss;
v       = vss;
u       = 1-(1-rhoss)*n; 
ur      = 1-n; 
q       = qss;
s       = sss;
wr      = Wss;
c       = Css;
ytot    = Yss;
y       = alpha*ytot/n ;
curlphi = (epsilon-1)/epsilon;
rk      = RKss;
pie     = piess;
piew    = piewss;
gampi   = 0;
DGampi  = 0;
wrc     = 0;
dwrc    = 0;
nint    = Rss;

z       = 0;
risk     = 0;
e_m     = 0;
end;

shocks;
    var e_m = 0.0001;   // monetary
    var e_r = 0.0001;   // risk premium
    var e_z = 0.0001;   // transitory technology
end;

steady;

addnames('ytot',   'Production');
addnames('pie',    'Price inflation');
addnames('piew',   'Wage inflation');
addnames('ur',     'Unemployment rate');
addnames('wr',     'Real wage');
addnames('n',      'Employment');
addnames('q',      'Job filling rate');
addnames('v',      'Vacancies');
addnames('nint',   'Nominal interest rate');
addnames('inv',    'Investment');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%    Common block for all parts      %%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

options_.pruning    = 1;
options_.relative_irf= 1;
options_.nocorr     = 1;
options_.nomoments  = 1;
options_.noprint    = 1;
options_.simul_seed = 123123;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%        Initialization                           %%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

stoch_simul(periods=1000,irf=0) ytot pie piew ur wr n inv nint v;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%        Second moments and skewness              %%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

dwmoments

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%        Harding and Pagan Analysis on selected variables;     %%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

dw_turningpoints

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%        Impulse responses                                     %%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

myirfreplic     = 300; //5000
myirflength     = 15;
myirfstartval   = 0;
momreplic       = 1;
modname1        = strcat('DNWR');

varirf      = strvcat('piew','inv','v','pie','n','ur','wr','ytot','nint'); 

% Technology shock
myshocktypes    = ['e_z']; 
myshocksize     = [-2;2];
%dynareirf(myshocktypes,myirfreplic,myirflength,varirf,myshocksize,myirfstartval,modname1)

% Risk premium shock
myshocktypes    = ['e_r']; 
myshocksize     = [2.5;-2.5];
%dynareirf(myshocktypes,myirfreplic,myirflength,varirf,myshocksize,myirfstartval,modname1)

% Monetary policy shock
myshocktypes    = ['e_m']; 
myshocksize     = [-2.5;2.5];
%dynareirf(myshocktypes,myirfreplic,myirflength,varirf,myshocksize,myirfstartval,modname1)
